# Audio

Audio loading, mixing, effects, and analysis modules.

## AudioClip

::: pymotion.clip.audio.AudioClip

## AudioMixer

::: pymotion.audio.mixer.AudioMixer

## AudioClipData

::: pymotion.audio.mixer.AudioClipData

## Effects

::: pymotion.audio.effects.Compressor

::: pymotion.audio.effects.Limiter

::: pymotion.audio.effects.EQ

::: pymotion.audio.effects.EQBand

## Analysis

::: pymotion.audio.analysis.BeatDetector

::: pymotion.audio.analysis.OnsetDetector

::: pymotion.audio.analysis.WaveformExtractor

::: pymotion.audio.analysis.waveform_to_keyframes
